@@ -1,4 +1,4 @@
-use crate::{http::StatusCode, Endpoint, Request, Response};
+use crate::{http::StatusCode, Endpoint, IntoResponse, Request, Response};
 
 /// Endpoint for the [`or`](super::EndpointExt::or) method.
 pub struct Or<A, B>(A, B);
@@ -15,11 +15,13 @@ where
     A: Endpoint,
     B: Endpoint,
 {
+    type Output = Response;
+
     async fn call(&self, req: Request) -> Response {
         return if self.0.check(&req) {
-            self.0.call(req).await
+            self.0.call(req).await.into_response()
         } else if self.1.check(&req) {
-            self.1.call(req).await
+            self.1.call(req).await.into_response()
         } else {
             StatusCode::NOT_FOUND.into()
         };
